@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -170,11 +170,14 @@ BEGIN {
 							value => $options 
 						};
 					}
-					$PRO{set_prop}(
-						$caller,
-						$prop,
-						%{$options}
-					);
+
+					for (ref $prop ? @{$prop} : ($prop)) {
+						$PRO{set_prop}(
+							$caller,
+							$_,
+							%{$options}
+						)
+					};
 				}
 			};
 		},
@@ -186,11 +189,13 @@ BEGIN {
 				if (scalar @options % 2) {
 					$prop = shift @options;
 				}
-				$PRO{set_prop}(
-					$caller,
-					$prop,
-					@options
-				);
+				for (ref $prop ? @{$prop} : ($prop)) {
+					$PRO{set_prop}(
+						$caller,
+						$_,
+						@options
+					);
+				}
 			};
 		},
 		prototyped => sub {
@@ -200,15 +205,17 @@ BEGIN {
 				my (@proto) = @_;
 				while (@proto) {
 					my ($prop, $value) = (shift @proto, shift @proto);
-					$PRO{set_prop}(
-						$caller,
-						$prop,
-						enumerable => 1,
-						writeable => 1,
-						configurable => 1,
-						initable => 1,
-						value => $value
-					);
+					for (ref $prop ? @{$prop} : ($prop)) {
+						$PRO{set_prop}(
+							$caller,
+							$_,
+							enumerable => 1,
+							writeable => 1,
+							configurable => 1,
+							initable => 1,
+							value => $value
+						);
+					}
 				}
 			}
 		},
@@ -611,7 +618,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
@@ -738,6 +745,7 @@ Extends the current object definition with a single new property
 		}
 	);
 
+	property [qw/a b c/] => ( ... );
 
 =head2 properties
 
@@ -752,6 +760,7 @@ Extends the current object definition with multiple new properties
 			enumerable => 1,
 			required => 1
 		},
+		[qw/a b c/] => { ... }
 		...
 	);
 
@@ -760,7 +769,8 @@ Extends the current object definition with multiple new properties
 Extends the current object definition with multiple new properties where initable, writable and enumerable are all set to a true value.
 
 	prototyped (
-		two => 10
+		three => 10
+		[qw/a b c/] => 211
 		...
 	);
 
@@ -768,14 +778,14 @@ Extends the current object definition with multiple new properties where initabl
 
 Extends the current object definition with a new property that acts as a function. A function has initable, writeable, enumerable and configurable all set to false so it cannot be changed/set once the object is instantiated.
 
-	function three => sub {
+	function four => sub {
 		my ($self, $param) = @_;
 		...
 	};
 
 NOTE: traditional sub routines work and should be inherited also.	
 
-	sub three {
+	sub four {
 		my ($self, $param) = @_;
 		...
 	}
